@@ -1,26 +1,12 @@
 /****************************************************************************
  *                 Basic manipulation of XStringSet objects                 *
- *                           Author: Herve Pages                            *
+ *                            Author: H. Pag\`es                            *
  ****************************************************************************/
 #include "Biostrings.h"
 #include "XVector_interface.h"
 #include "IRanges_interface.h"
 #include "S4Vectors_interface.h"
 
-static int debug = 0;
-
-SEXP debug_XStringSet_class()
-{
-#ifdef DEBUG_BIOSTRINGS
-	debug = !debug;
-	Rprintf("Debug mode turned %s in file %s\n",
-		debug ? "on" : "off", __FILE__);
-#else
-	Rprintf("Debug mode not available in file %s\n", __FILE__);
-#endif
-	return R_NilValue;
-}
-
 
 /****************************************************************************
  * C-level slot getters.
